==> codeready-workspaces-2.5.0-GA-crwctl3-sources.tar.gz: crwctl/lib/api/version.js <==
"use strict";
/*********************************************************************
 * Copyright (c) 2020 Red Hat, Inc.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 **********************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.VersionHelper = void 0;
const tslib_1 = require("tslib");
const execa = require("execa");
const che_1 = require("../tasks/che");
const util_1 = require("../util");
const kube_1 = require("./kube");
var VersionHelper;
(function (VersionHelper) {
    VersionHelper.MINIMAL_OPENSHIFT_VERSION = '3.11';
    VersionHelper.MINIMAL_K8S_VERSION = '1.9';
    VersionHelper.MINIMAL_HELM_VERSION = '2.15';
    VersionHelper.CHE_POD_MANIFEST_FILE = '/home/user/eclipse-che/tomcat/webapps/ROOT/META-INF/MANIFEST.MF';
    VersionHelper.CHE_PREFFIX_VERSION = 'Implementation-Version: ';
    function getOpenShiftCheckVersionTask(flags) {
        return {
            title: 'Check OpenShift version',
            task: (_ctx, task) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                const kubeHelper = new kube_1.KubeHelper(flags);
                const actualVersion = yield getOpenShiftVersion();
                if (actualVersion) {
                    task.title = `${task.title}: ${actualVersion}.`;
                }
                else if (yield kubeHelper.isOpenShift4()) {
                    task.title = `${task.title}: 4.x`;
                }
                else {
                    task.title = `${task.title}: Unknown`;
                }
                if (!flags['skip-version-check'] && actualVersion) {
                    const checkPassed = checkMinimalVersion(actualVersion, VersionHelper.MINIMAL_OPENSHIFT_VERSION);
                    if (!checkPassed) {
                        throw getError('OpenShift', actualVersion, VersionHelper.MINIMAL_OPENSHIFT_VERSION);
                    }
                }
            })
        };
    }
    VersionHelper.getOpenShiftCheckVersionTask = getOpenShiftCheckVersionTask;
    function getK8sCheckVersionTask(flags) {
        return {
            title: 'Check Kubernetes version',
            task: (_ctx, task) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                let actualVersion;
                switch (flags.platform) {
                    case 'minishift':
                    case 'openshift':
                    case 'crc':
                        actualVersion = yield getK8sVersionWithOC();
                        break;
                    default:
                        actualVersion = yield getK8sVersionWithKubectl();
                }
                if (actualVersion) {
                    task.title = `${task.title}: Found ${actualVersion}.`;
                }
                else {
                    task.title = `${task.title}: Unknown.`;
                }
                if (!flags['skip-version-check'] && actualVersion) {
                    const checkPassed = checkMinimalVersion(actualVersion, VersionHelper.MINIMAL_K8S_VERSION);
                    if (!checkPassed) {
                        throw getError('Kubernetes', actualVersion, VersionHelper.MINIMAL_K8S_VERSION);
                    }
                }
            })
        };
    }
    VersionHelper.getK8sCheckVersionTask = getK8sCheckVersionTask;
    function getOpenShiftVersion() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return getVersionWithOC('openshift ');
        });
    }
    VersionHelper.getOpenShiftVersion = getOpenShiftVersion;
    function getK8sVersionWithOC() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return getVersionWithOC('kubernetes ');
        });
    }
    VersionHelper.getK8sVersionWithOC = getK8sVersionWithOC;
    function getK8sVersionWithKubectl() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return getVersionWithKubectl('Server Version: ');
        });
    }
    VersionHelper.getK8sVersionWithKubectl = getK8sVersionWithKubectl;
    function checkMinimalK8sVersion(actualVersion) {
        return checkMinimalVersion(actualVersion, VersionHelper.MINIMAL_K8S_VERSION);
    }
    VersionHelper.checkMinimalK8sVersion = checkMinimalK8sVersion;
    function checkMinimalOpenShiftVersion(actualVersion) {
        return checkMinimalVersion(actualVersion, VersionHelper.MINIMAL_OPENSHIFT_VERSION);
    }
    VersionHelper.checkMinimalOpenShiftVersion = checkMinimalOpenShiftVersion;
    function checkMinimalHelmVersion(actualVersion) {
        return checkMinimalVersion(actualVersion, VersionHelper.MINIMAL_HELM_VERSION);
    }
    VersionHelper.checkMinimalHelmVersion = checkMinimalHelmVersion;
    /**
     * Compare versions and return true if actual version is greater or equal to minimal.
     * The comparison will be done by major and minor versions.
     */
    function checkMinimalVersion(actual, minimal) {
        actual = removeVPrefix(actual);
        let vers = actual.split('.');
        const actualMajor = parseInt(vers[0], 10);
        const actualMinor = parseInt(vers[1], 10);
        minimal = removeVPrefix(minimal);
        vers = minimal.split('.');
        const minimalMajor = parseInt(vers[0], 10);
        const minimalMinor = parseInt(vers[1], 10);
        return (actualMajor > minimalMajor || (actualMajor === minimalMajor && actualMinor >= minimalMinor));
    }
    VersionHelper.checkMinimalVersion = checkMinimalVersion;
    function getError(actualVersion, minimalVersion, component) {
        return new Error(`The minimal supported version of ${component} is '${minimalVersion} but found '${actualVersion}'. To bypass version check use '--skip-version-check' flag.`);
    }
    VersionHelper.getError = getError;
    function getVersionWithOC(versionPrefix) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const command = 'oc';
            const args = ['version'];
            const { stdout } = yield execa(command, args, { timeout: 60000 });
            return stdout.split('\n').filter(value => value.startsWith(versionPrefix)).map(value => value.substring(versionPrefix.length))[0];
        });
    }
    function getVersionWithKubectl(versionPrefix) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const command = 'kubectl';
            const args = ['version', '--short'];
            const { stdout } = yield execa(command, args, { timeout: 60000 });
            return stdout.split('\n').filter(value => value.startsWith(versionPrefix)).map(value => value.substring(versionPrefix.length))[0];
        });
    }
    /**
     * Returns CodeReady Workspaces version.
     */
    function getCheVersion(flags) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const kube = new kube_1.KubeHelper(flags);
            const cheTasks = new che_1.CheTasks(flags);
            const cheCluster = yield kube.getCheCluster(flags.chenamespace);
            if (cheCluster && cheCluster.spec.server.cheFlavor !== 'che') {
                return cheCluster.status.cheVersion;
            }
            const chePodList = yield kube.getPodListByLabel(flags.chenamespace, cheTasks.cheSelector);
            const [chePodName] = chePodList.map(pod => pod.metadata && pod.metadata.name);
            if (!chePodName) {
                return 'UNKNOWN';
            }
            const command = util_1.getClusterClientCommand();
            const args = ['exec', chePodName, '--namespace', flags.chenamespace, 'cat', VersionHelper.CHE_POD_MANIFEST_FILE];
            try {
                const { stdout } = yield execa(command, args, { timeout: 60000 });
                return stdout.split('\n').filter(value => value.startsWith(VersionHelper.CHE_PREFFIX_VERSION)).map(value => value.substring(VersionHelper.CHE_PREFFIX_VERSION.length))[0];
            }
            catch (_a) {
                return 'UNKNOWN';
            }
        });
    }
    VersionHelper.getCheVersion = getCheVersion;
    function removeVPrefix(version) {
        return version.startsWith('v') ? version.substring(1) : version;
    }
})(VersionHelper = exports.VersionHelper || (exports.VersionHelper = {}));
//# sourceMappingURL=version.js.map

==> codeready-workspaces-2.6.0-GA-crwctl3-sources.tar.gz: crwctl/lib/api/version.js <==
"use strict";
/*********************************************************************
 * Copyright (c) 2020 Red Hat, Inc.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 **********************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.VersionHelper = void 0;
const tslib_1 = require("tslib");
const execa = require("execa");
const che_1 = require("../tasks/che");
const util_1 = require("../util");
const kube_1 = require("./kube");
var VersionHelper;
(function (VersionHelper) {
    VersionHelper.MINIMAL_OPENSHIFT_VERSION = '3.11';
    VersionHelper.MINIMAL_K8S_VERSION = '1.9';
    VersionHelper.MINIMAL_HELM_VERSION = '2.15';
    VersionHelper.CHE_POD_MANIFEST_FILE = '/home/user/eclipse-che/tomcat/webapps/ROOT/META-INF/MANIFEST.MF';
    VersionHelper.CHE_PREFFIX_VERSION = 'Implementation-Version: ';
    function getOpenShiftCheckVersionTask(flags) {
        return {
            title: 'Check OpenShift version',
            task: (ctx, task) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                const actualVersion = yield getOpenShiftVersion();
                if (actualVersion) {
                    task.title = `${task.title}: ${actualVersion}.`;
                }
                else if (ctx.isOpenShift4) {
                    task.title = `${task.title}: 4.x`;
                }
                else {
                    task.title = `${task.title}: Unknown`;
                }
                if (!flags['skip-version-check'] && actualVersion) {
                    const checkPassed = checkMinimalVersion(actualVersion, VersionHelper.MINIMAL_OPENSHIFT_VERSION);
                    if (!checkPassed) {
                        throw getError('OpenShift', actualVersion, VersionHelper.MINIMAL_OPENSHIFT_VERSION);
                    }
                }
            })
        };
    }
    VersionHelper.getOpenShiftCheckVersionTask = getOpenShiftCheckVersionTask;
    function getK8sCheckVersionTask(flags) {
        return {
            title: 'Check Kubernetes version',
            task: (_ctx, task) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                let actualVersion;
                switch (flags.platform) {
                    case 'minishift':
                    case 'openshift':
                    case 'crc':
                        actualVersion = yield getK8sVersionWithOC();
                        break;
                    default:
                        actualVersion = yield getK8sVersionWithKubectl();
                }
                if (actualVersion) {
                    task.title = `${task.title}: Found ${actualVersion}.`;
                }
                else {
                    task.title = `${task.title}: Unknown.`;
                }
                if (!flags['skip-version-check'] && actualVersion) {
                    const checkPassed = checkMinimalVersion(actualVersion, VersionHelper.MINIMAL_K8S_VERSION);
                    if (!checkPassed) {
                        throw getError('Kubernetes', actualVersion, VersionHelper.MINIMAL_K8S_VERSION);
                    }
                }
            })
        };
    }
    VersionHelper.getK8sCheckVersionTask = getK8sCheckVersionTask;
    function getOpenShiftVersion() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return getVersionWithOC('openshift ');
        });
    }
    VersionHelper.getOpenShiftVersion = getOpenShiftVersion;
    function getK8sVersionWithOC() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return getVersionWithOC('kubernetes ');
        });
    }
    VersionHelper.getK8sVersionWithOC = getK8sVersionWithOC;
    function getK8sVersionWithKubectl() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return getVersionWithKubectl('Server Version: ');
        });
    }
    VersionHelper.getK8sVersionWithKubectl = getK8sVersionWithKubectl;
    function checkMinimalK8sVersion(actualVersion) {
        return checkMinimalVersion(actualVersion, VersionHelper.MINIMAL_K8S_VERSION);
    }
    VersionHelper.checkMinimalK8sVersion = checkMinimalK8sVersion;
    function checkMinimalOpenShiftVersion(actualVersion) {
        return checkMinimalVersion(actualVersion, VersionHelper.MINIMAL_OPENSHIFT_VERSION);
    }
    VersionHelper.checkMinimalOpenShiftVersion = checkMinimalOpenShiftVersion;
    function checkMinimalHelmVersion(actualVersion) {
        return checkMinimalVersion(actualVersion, VersionHelper.MINIMAL_HELM_VERSION);
    }
    VersionHelper.checkMinimalHelmVersion = checkMinimalHelmVersion;
    /**
     * Compare versions and return true if actual version is greater or equal to minimal.
     * The comparison will be done by major and minor versions.
     */
    function checkMinimalVersion(actual, minimal) {
        actual = removeVPrefix(actual);
        let vers = actual.split('.');
        const actualMajor = parseInt(vers[0], 10);
        const actualMinor = parseInt(vers[1], 10);
        minimal = removeVPrefix(minimal);
        vers = minimal.split('.');
        const minimalMajor = parseInt(vers[0], 10);
        const minimalMinor = parseInt(vers[1], 10);
        return (actualMajor > minimalMajor || (actualMajor === minimalMajor && actualMinor >= minimalMinor));
    }
    VersionHelper.checkMinimalVersion = checkMinimalVersion;
    function getError(actualVersion, minimalVersion, component) {
        return new Error(`The minimal supported version of ${component} is '${minimalVersion} but found '${actualVersion}'. To bypass version check use '--skip-version-check' flag.`);
    }
    VersionHelper.getError = getError;
    function getVersionWithOC(versionPrefix) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const command = 'oc';
            const args = ['version'];
            const { stdout } = yield execa(command, args, { timeout: 60000 });
            return stdout.split('\n').filter(value => value.startsWith(versionPrefix)).map(value => value.substring(versionPrefix.length))[0];
        });
    }
    function getVersionWithKubectl(versionPrefix) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const command = 'kubectl';
            const args = ['version', '--short'];
            const { stdout } = yield execa(command, args, { timeout: 60000 });
            return stdout.split('\n').filter(value => value.startsWith(versionPrefix)).map(value => value.substring(versionPrefix.length))[0];
        });
    }
    /**
     * Returns CodeReady Workspaces version.
     */
    function getCheVersion(flags) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const kube = new kube_1.KubeHelper(flags);
            const cheTasks = new che_1.CheTasks(flags);
            const cheCluster = yield kube.getCheCluster(flags.chenamespace);
            if (cheCluster && cheCluster.spec.server.cheFlavor !== 'che') {
                return cheCluster.status.cheVersion;
            }
            const chePodList = yield kube.getPodListByLabel(flags.chenamespace, cheTasks.cheSelector);
            const [chePodName] = chePodList.map(pod => pod.metadata && pod.metadata.name);
            if (!chePodName) {
                return 'UNKNOWN';
            }
            const command = util_1.getClusterClientCommand();
            const args = ['exec', chePodName, '--namespace', flags.chenamespace, 'cat', VersionHelper.CHE_POD_MANIFEST_FILE];
            try {
                const { stdout } = yield execa(command, args, { timeout: 60000 });
                return stdout.split('\n').filter(value => value.startsWith(VersionHelper.CHE_PREFFIX_VERSION)).map(value => value.substring(VersionHelper.CHE_PREFFIX_VERSION.length))[0];
            }
            catch (_a) {
                return 'UNKNOWN';
            }
        });
    }
    VersionHelper.getCheVersion = getCheVersion;
    function removeVPrefix(version) {
        return version.startsWith('v') ? version.substring(1) : version;
    }
})(VersionHelper = exports.VersionHelper || (exports.VersionHelper = {}));
//# sourceMappingURL=version.js.map
